@@ -32,31 +32,31 @@ func (c *authOperator) handleBrandingTemplates(configTemplates configv1.OAuthTem
 	case ocpBrand, "dedicated", "online", "azure":
 		// all of these are equivalent to ocp
 		templates = osinv1.OAuthTemplates{
-			Login:             ocpBrandingLoginPath,
-			ProviderSelection: ocpBrandingProviderPath,
-			Error:             ocpBrandingErrorPath,
+			Login:             "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/login.html",
+			ProviderSelection: "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/providers.html",
+			Error:             "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/errors.html",
 		}
 
 	default:
 		if defaultBrand == ocpBrand {
 			// build-time ocp selection
 			templates = osinv1.OAuthTemplates{
-				Login:             ocpBrandingLoginPath,
-				ProviderSelection: ocpBrandingProviderPath,
-				Error:             ocpBrandingErrorPath,
+				Login:             "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/login.html",
+				ProviderSelection: "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/providers.html",
+				Error:             "/var/config/system/secrets/v4-0-config-system-ocp-branding-template/errors.html",
 			}
 		}
 	}
 
 	// user-configured overrides everything else, individually.
 	if hasSecretRef(configTemplates.Login) {
-		templates.Login = syncData.addTemplateSecret(configTemplates.Login, loginField, configv1.LoginTemplateKey)
+		templates.Login = syncData.addTemplateSecret(configTemplates.Login, "login", configv1.LoginTemplateKey)
 	}
 	if hasSecretRef(configTemplates.ProviderSelection) {
-		templates.ProviderSelection = syncData.addTemplateSecret(configTemplates.ProviderSelection, providerSelectionField, configv1.ProviderSelectionTemplateKey)
+		templates.ProviderSelection = syncData.addTemplateSecret(configTemplates.ProviderSelection, "provider-selection", configv1.ProviderSelectionTemplateKey)
 	}
 	if hasSecretRef(configTemplates.Error) {
-		templates.Error = syncData.addTemplateSecret(configTemplates.Error, errorField, configv1.ErrorsTemplateKey)
+		templates.Error = syncData.addTemplateSecret(configTemplates.Error, "error", configv1.ErrorsTemplateKey)
 	}
 
 	empty := osinv1.OAuthTemplates{}
@@ -68,7 +68,7 @@ func (c *authOperator) handleBrandingTemplates(configTemplates configv1.OAuthTem
 }
 
 func (c *authOperator) getConsoleBranding() (string, error) {
-	cm, err := c.configMaps.ConfigMaps(targetNamespace).Get(consoleConfigMapLocalName, metav1.GetOptions{})
+	cm, err := c.configMaps.ConfigMaps("openshift-authentication").Get("v4-0-config-system-console-config", metav1.GetOptions{})
 	if errors.IsNotFound(err) {
 		return "", nil
 	}
@@ -76,7 +76,7 @@ func (c *authOperator) getConsoleBranding() (string, error) {
 		return "", fmt.Errorf("error getting console-config: %v", err)
 	}
 
-	data := cm.Data[consoleConfigKey]
+	data := cm.Data["console-config.yaml"]
 	if len(data) == 0 {
 		return "", nil
 	}
