@@ -9,25 +9,25 @@ import (
 func (c *authOperator) handleConfigResourceVersions() ([]string, error) {
 	var configRVs []string
 
-	configMaps, err := c.configMaps.ConfigMaps(targetNamespace).List(metav1.ListOptions{})
+	configMaps, err := c.configMaps.ConfigMaps("openshift-authentication").List(metav1.ListOptions{})
 	if err != nil {
 		return nil, err
 	}
 	for _, cm := range configMaps.Items {
-		if strings.HasPrefix(cm.Name, configVersionPrefix) {
+		if strings.HasPrefix(cm.Name, "v4-0-config-") {
 			// prefix the RV to make it clear where it came from since each resource can be from different etcd
-			configRVs = append(configRVs, "configmaps:"+cm.ResourceVersion)
+			configRVs = append(configRVs, "configmaps:"+cm.Name+":"+cm.ResourceVersion)
 		}
 	}
 
-	secrets, err := c.secrets.Secrets(targetNamespace).List(metav1.ListOptions{})
+	secrets, err := c.secrets.Secrets("openshift-authentication").List(metav1.ListOptions{})
 	if err != nil {
 		return nil, err
 	}
 	for _, secret := range secrets.Items {
-		if strings.HasPrefix(secret.Name, configVersionPrefix) {
+		if strings.HasPrefix(secret.Name, "v4-0-config-") {
 			// prefix the RV to make it clear where it came from since each resource can be from different etcd
-			configRVs = append(configRVs, "secrets:"+secret.ResourceVersion)
+			configRVs = append(configRVs, "secrets:"+secret.Name+":"+secret.ResourceVersion)
 		}
 	}
 
