@@ -29,6 +29,7 @@ import (
 	"github.com/openshift/library-go/pkg/operator/unsupportedconfigoverridescontroller"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
 
+	"github.com/openshift/cluster-authentication-operator/pkg/controller/ingressstate"
 	"github.com/openshift/cluster-authentication-operator/pkg/operator2/routercerts"
 )
 
@@ -36,31 +37,31 @@ const (
 	resync = 20 * time.Minute
 )
 
-func RunOperator(ctx *controllercmd.ControllerContext) error {
+func RunOperator(ctx context.Context, controllerContext *controllercmd.ControllerContext) error {
 	// protobuf can be used with non custom resources
-	kubeClient, err := kubernetes.NewForConfig(ctx.ProtoKubeConfig)
+	kubeClient, err := kubernetes.NewForConfig(controllerContext.ProtoKubeConfig)
 	if err != nil {
 		return err
 	}
 
-	authConfigClient, err := authopclient.NewForConfig(ctx.KubeConfig)
+	authConfigClient, err := authopclient.NewForConfig(controllerContext.KubeConfig)
 	if err != nil {
 		return err
 	}
 
 	// protobuf can be used with non custom resources
-	routeClient, err := routeclient.NewForConfig(ctx.ProtoKubeConfig)
+	routeClient, err := routeclient.NewForConfig(controllerContext.ProtoKubeConfig)
 	if err != nil {
 		return err
 	}
 
 	// protobuf can be used with non custom resources
-	oauthClient, err := oauthclient.NewForConfig(ctx.ProtoKubeConfig)
+	oauthClient, err := oauthclient.NewForConfig(controllerContext.ProtoKubeConfig)
 	if err != nil {
 		return err
 	}
 
-	configClient, err := configclient.NewForConfig(ctx.KubeConfig)
+	configClient, err := configclient.NewForConfig(controllerContext.KubeConfig)
 	if err != nil {
 		return err
 	}
@@ -69,7 +70,12 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		informers.WithNamespace("openshift-authentication"),
 	)
 
-	authOperatorConfigInformers := authopinformer.NewSharedInformerFactoryWithOptions(authConfigClient, resync,
+	kubeSystemNamespaceInformers := informers.NewSharedInformerFactoryWithOptions(kubeClient, resync,
+		informers.WithNamespace("kube-system"),
+	)
+
+	// short resync period as this drives the check frequency when checking the .well-known endpoint. 20 min is too slow for that.
+	authOperatorConfigInformers := authopinformer.NewSharedInformerFactoryWithOptions(authConfigClient, time.Second*30,
 		authopinformer.WithTweakListOptions(singleNameListOptions("cluster")),
 	)
 
@@ -99,7 +105,7 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		resourceSyncerInformers,
 		v1helpers.CachedSecretGetter(kubeClient.CoreV1(), resourceSyncerInformers),
 		v1helpers.CachedConfigMapGetter(kubeClient.CoreV1(), resourceSyncerInformers),
-		ctx.EventRecorder,
+		controllerContext.EventRecorder,
 	)
 
 	// add syncing for the OAuth metadata ConfigMap
@@ -132,13 +138,14 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		*operatorClient,
 		oauthClient.OauthV1(),
 		kubeInformersNamespaced,
+		kubeSystemNamespaceInformers,
 		kubeClient,
 		routeInformersNamespaced.Route().V1().Routes(),
 		routeClient.RouteV1(),
 		configInformers,
 		configClient,
 		versionGetter,
-		ctx.EventRecorder,
+		controllerContext.EventRecorder,
 		resourceSyncer,
 	)
 
@@ -161,7 +168,7 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		configInformers.Config().V1().ClusterOperators(),
 		operatorClient,
 		versionGetter,
-		ctx.EventRecorder,
+		controllerContext.EventRecorder,
 	)
 
 	staleConditions := staleconditions.NewRemoveStaleConditions(
@@ -170,15 +177,15 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 			"Degraded",
 		},
 		operatorClient,
-		ctx.EventRecorder,
+		controllerContext.EventRecorder,
 	)
 
-	configOverridesController := unsupportedconfigoverridescontroller.NewUnsupportedConfigOverridesController(operatorClient, ctx.EventRecorder)
-	logLevelController := loglevel.NewClusterOperatorLoggingController(operatorClient, ctx.EventRecorder)
+	configOverridesController := unsupportedconfigoverridescontroller.NewUnsupportedConfigOverridesController(operatorClient, controllerContext.EventRecorder)
+	logLevelController := loglevel.NewClusterOperatorLoggingController(operatorClient, controllerContext.EventRecorder)
 
 	routerCertsController := routercerts.NewRouterCertsDomainValidationController(
 		operatorClient,
-		ctx.EventRecorder,
+		controllerContext.EventRecorder,
 		configInformers.Config().V1().Ingresses(),
 		kubeInformersNamespaced.Core().V1().Secrets(),
 		"openshift-authentication",
@@ -186,23 +193,31 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		"oauth-openshift",
 	)
 
+	ingressStateController := ingressstate.NewIngressStateController(
+		kubeInformersNamespaced,
+		kubeClient.CoreV1(),
+		kubeClient.CoreV1(),
+		operatorClient,
+		"openshift-authentication",
+		controllerContext.EventRecorder)
+
 	// TODO remove this controller once we support Removed
-	managementStateController := management.NewOperatorManagementStateController("authentication", operatorClient, ctx.EventRecorder)
+	managementStateController := management.NewOperatorManagementStateController("authentication", operatorClient, controllerContext.EventRecorder)
 	management.SetOperatorNotRemovable()
 	// TODO move to config observers
 	// configobserver.NewConfigObserver(...)
-	processCtx := ctx.Ctx
 
 	for _, informer := range []interface {
 		Start(stopCh <-chan struct{})
 	}{
 		kubeInformersNamespaced,
+		kubeSystemNamespaceInformers,
 		authOperatorConfigInformers,
 		routeInformersNamespaced,
 		configInformers,
 		resourceSyncerInformers,
 	} {
-		informer.Start(processCtx.Done())
+		informer.Start(ctx.Done())
 	}
 
 	for _, controller := range []interface {
@@ -215,13 +230,14 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		routerCertsController,
 		managementStateController,
 	} {
-		go controller.Run(processCtx, 1)
+		go controller.Run(ctx, 1)
 	}
 
-	go operator.Run(processCtx.Done())
-	go staleConditions.Run(1, processCtx.Done())
+	go operator.Run(ctx.Done())
+	go staleConditions.Run(1, ctx.Done())
+	go ingressStateController.Run(1, ctx.Done())
 
-	<-processCtx.Done()
+	<-ctx.Done()
 
 	return fmt.Errorf("stopped")
 }
